@@ -8,5 +8,5 @@ import tldextract
 def test_bad_kwargs():
     with pytest.raises(ValueError):
         tldextract.TLDExtract(
-            cache_dir=False, suffix_list_urls=False, fallback_to_snapshot=False
+            cache_dir=None, suffix_list_urls=(), fallback_to_snapshot=False
         )
